#[non_exhaustive]pub enum Event {
ToplevelEnter {
toplevel: ExtForeignToplevelHandleV1,
x: i32,
y: i32,
width: i32,
height: i32,
},
ToplevelLeave {
toplevel: ExtForeignToplevelHandleV1,
},
LayerEnter {
identifier: String,
namespace: String,
exclusive: u32,
layer: WEnum<Layer>,
x: i32,
y: i32,
width: i32,
height: i32,
},
LayerLeave {
identifier: String,
},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ToplevelEnter
Toplevel entered the surface area
A ext_foreign_toplevel_handle_v1 has entered the surface area.
This event will be emitted once for every ext_foreign_toplevel_handle_v1 representing this toplevel.
Compositors are free to update the overlapping area by sending additional
toplevel_enter events for the same toplevel without sending toplevel_leave
in between.
Fields
toplevel: ExtForeignToplevelHandleV1ToplevelLeave
Toplevel entered the surface area
A ext_foreign_toplevel_handle_v1 has left the surface area.
This event will be emitted once for every ext_foreign_toplevel_handle_v1 representing this toplevel.
Fields
toplevel: ExtForeignToplevelHandleV1LayerEnter
Layer surface entered the surface area
A zwlr_layer_surface_v1 has entered the surface area.
Compositors are free to update the overlapping area by sending additional
layer_enter events for the same surface without sending layer_leave
in between.
The overlapping region is given surface-relative to the zwlr_layer_surface_v1 used to create this notification object.
Fields
LayerLeave
Layer surface left the surface area
A zwlr_layer_surface_v1 has left the surface area.
Implementations